@@ -15,7 +15,7 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
+from .utils import SKIP_IN_PATH, NamespacedClient, _make_path, query_params
 
 
 class CcrClient(NamespacedClient):
@@ -24,7 +24,7 @@ class CcrClient(NamespacedClient):
         """
         Deletes auto-follow patterns.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-delete-auto-follow-pattern.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ccr-delete-auto-follow-pattern.html>`_
 
         :arg name: The name of the auto follow pattern.
         """
@@ -43,7 +43,7 @@ class CcrClient(NamespacedClient):
         """
         Creates a new follower index configured to follow the referenced leader index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-put-follow.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ccr-put-follow.html>`_
 
         :arg index: The name of the follower index
         :arg body: The name of the leader index and other optional ccr
@@ -72,7 +72,7 @@ class CcrClient(NamespacedClient):
         Retrieves information about all follower indices, including parameters and
         status for each follower index
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-get-follow-info.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ccr-get-follow-info.html>`_
 
         :arg index: A comma-separated list of index patterns; use `_all`
             to perform the operation on all indices
@@ -90,7 +90,7 @@ class CcrClient(NamespacedClient):
         Retrieves follower stats. return shard-level stats about the following tasks
         associated with each shard for the specified indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-get-follow-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ccr-get-follow-stats.html>`_
 
         :arg index: A comma-separated list of index patterns; use `_all`
             to perform the operation on all indices
@@ -107,7 +107,7 @@ class CcrClient(NamespacedClient):
         """
         Removes the follower retention leases from the leader.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-post-forget-follower.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ccr-post-forget-follower.html>`_
 
         :arg index: the name of the leader index for which specified
             follower retention leases should be removed
@@ -134,7 +134,7 @@ class CcrClient(NamespacedClient):
         Gets configured auto-follow patterns. Returns the specified auto-follow pattern
         collection.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-get-auto-follow-pattern.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ccr-get-auto-follow-pattern.html>`_
 
         :arg name: The name of the auto follow pattern.
         """
@@ -151,7 +151,7 @@ class CcrClient(NamespacedClient):
         Pauses a follower index. The follower index will not fetch any additional
         operations from the leader index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-post-pause-follow.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ccr-post-pause-follow.html>`_
 
         :arg index: The name of the follower index that should pause
             following its leader index.
@@ -173,7 +173,7 @@ class CcrClient(NamespacedClient):
         remote cluster. Newly created indices on the remote cluster matching any of the
         specified patterns will be automatically configured as follower indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-put-auto-follow-pattern.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ccr-put-auto-follow-pattern.html>`_
 
         :arg name: The name of the auto follow pattern.
         :arg body: The specification of the auto follow pattern
@@ -195,7 +195,7 @@ class CcrClient(NamespacedClient):
         """
         Resumes a follower index that has been paused
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-post-resume-follow.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ccr-post-resume-follow.html>`_
 
         :arg index: The name of the follow index to resume following.
         :arg body: The name of the leader index and other optional ccr
@@ -217,7 +217,7 @@ class CcrClient(NamespacedClient):
         """
         Gets all stats related to cross-cluster replication.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-get-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ccr-get-stats.html>`_
         """
         return await self.transport.perform_request(
             "GET", "/_ccr/stats", params=params, headers=headers
@@ -229,7 +229,7 @@ class CcrClient(NamespacedClient):
         Stops the following task associated with a follower index and removes index
         metadata and settings associated with cross-cluster replication.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-post-unfollow.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ccr-post-unfollow.html>`_
 
         :arg index: The name of the follower index that should be turned
             into a regular index.
@@ -249,7 +249,7 @@ class CcrClient(NamespacedClient):
         """
         Pauses an auto-follow pattern
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-pause-auto-follow-pattern.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ccr-pause-auto-follow-pattern.html>`_
 
         :arg name: The name of the auto follow pattern that should pause
             discovering new indices to follow.
@@ -269,7 +269,7 @@ class CcrClient(NamespacedClient):
         """
         Resumes an auto-follow pattern that has been paused
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-resume-auto-follow-pattern.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ccr-resume-auto-follow-pattern.html>`_
 
         :arg name: The name of the auto follow pattern to resume
             discovering new indices to follow.
