@@ -15,7 +15,7 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH, _bulk_body
+from .utils import SKIP_IN_PATH, NamespacedClient, _bulk_body, _make_path, query_params
 
 
 class MlClient(NamespacedClient):
@@ -25,7 +25,7 @@ class MlClient(NamespacedClient):
         Closes one or more anomaly detection jobs. A job can be opened and closed
         multiple times throughout its lifecycle.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-close-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-close-job.html>`_
 
         :arg job_id: The name of the job to close
         :arg body: The URL params optionally sent in the body
@@ -55,7 +55,7 @@ class MlClient(NamespacedClient):
         """
         Deletes a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-delete-calendar.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-calendar.html>`_
 
         :arg calendar_id: The ID of the calendar to delete
         """
@@ -76,7 +76,7 @@ class MlClient(NamespacedClient):
         """
         Deletes scheduled events from a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-delete-calendar-event.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-calendar-event.html>`_
 
         :arg calendar_id: The ID of the calendar to modify
         :arg event_id: The ID of the event to remove from the calendar
@@ -97,7 +97,7 @@ class MlClient(NamespacedClient):
         """
         Deletes anomaly detection jobs from a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-delete-calendar-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-calendar-job.html>`_
 
         :arg calendar_id: The ID of the calendar to modify
         :arg job_id: The ID of the job to remove from the calendar
@@ -118,7 +118,7 @@ class MlClient(NamespacedClient):
         """
         Deletes an existing datafeed.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-delete-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to delete
         :arg force: True if the datafeed should be forcefully deleted
@@ -140,7 +140,7 @@ class MlClient(NamespacedClient):
         """
         Deletes expired and unused machine learning data.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-delete-expired-data.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-expired-data.html>`_
 
         :arg body: deleting expired data parameters
         :arg job_id: The ID of the job(s) to perform expired data
@@ -163,7 +163,7 @@ class MlClient(NamespacedClient):
         """
         Deletes a filter.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-delete-filter.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-filter.html>`_
 
         :arg filter_id: The ID of the filter to delete
         """
@@ -182,7 +182,7 @@ class MlClient(NamespacedClient):
         """
         Deletes forecasts from a machine learning job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-delete-forecast.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-forecast.html>`_
 
         :arg job_id: The ID of the job from which to delete forecasts
         :arg forecast_id: The ID of the forecast to delete, can be comma
@@ -207,7 +207,7 @@ class MlClient(NamespacedClient):
         """
         Deletes an existing anomaly detection job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-delete-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-job.html>`_
 
         :arg job_id: The ID of the job to delete
         :arg force: True if the job should be forcefully deleted
@@ -229,7 +229,7 @@ class MlClient(NamespacedClient):
         """
         Deletes an existing model snapshot.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-delete-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-snapshot.html>`_
 
         :arg job_id: The ID of the job to fetch
         :arg snapshot_id: The ID of the snapshot to delete
@@ -247,85 +247,12 @@ class MlClient(NamespacedClient):
             headers=headers,
         )
 
-    @query_params(
-        "charset",
-        "column_names",
-        "delimiter",
-        "explain",
-        "format",
-        "grok_pattern",
-        "has_header_row",
-        "line_merge_size_limit",
-        "lines_to_sample",
-        "quote",
-        "should_trim_fields",
-        "timeout",
-        "timestamp_field",
-        "timestamp_format",
-    )
-    def find_file_structure(self, body, params=None, headers=None):
-        """
-        Finds the structure of a text file. The text file must contain data that is
-        suitable to be ingested into Elasticsearch.
-
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-find-file-structure.html>`_
-
-        .. warning::
-
-            This API is **experimental** so may include breaking changes
-            or be removed in a future version
-
-        :arg body: The contents of the file to be analyzed
-        :arg charset: Optional parameter to specify the character set of
-            the file
-        :arg column_names: Optional parameter containing a comma
-            separated list of the column names for a delimited file
-        :arg delimiter: Optional parameter to specify the delimiter
-            character for a delimited file - must be a single character
-        :arg explain: Whether to include a commentary on how the
-            structure was derived
-        :arg format: Optional parameter to specify the high level file
-            format  Valid choices: ndjson, xml, delimited, semi_structured_text
-        :arg grok_pattern: Optional parameter to specify the Grok
-            pattern that should be used to extract fields from messages in a semi-
-            structured text file
-        :arg has_header_row: Optional parameter to specify whether a
-            delimited file includes the column names in its first row
-        :arg line_merge_size_limit: Maximum number of characters
-            permitted in a single message when lines are merged to create messages.
-            Default: 10000
-        :arg lines_to_sample: How many lines of the file should be
-            included in the analysis  Default: 1000
-        :arg quote: Optional parameter to specify the quote character
-            for a delimited file - must be a single character
-        :arg should_trim_fields: Optional parameter to specify whether
-            the values between delimiters in a delimited file should have whitespace
-            trimmed from them
-        :arg timeout: Timeout after which the analysis will be aborted
-            Default: 25s
-        :arg timestamp_field: Optional parameter to specify the
-            timestamp field in the file
-        :arg timestamp_format: Optional parameter to specify the
-            timestamp format in the file - may be either a Joda or Java time format
-        """
-        if body in SKIP_IN_PATH:
-            raise ValueError("Empty value passed for a required argument 'body'.")
-
-        body = _bulk_body(self.transport.serializer, body)
-        return self.transport.perform_request(
-            "POST",
-            "/_ml/find_file_structure",
-            params=params,
-            headers=headers,
-            body=body,
-        )
-
     @query_params("advance_time", "calc_interim", "end", "skip_time", "start")
     def flush_job(self, job_id, body=None, params=None, headers=None):
         """
         Forces any buffered data to be processed by the job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-flush-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-flush-job.html>`_
 
         :arg job_id: The name of the job to flush
         :arg body: Flush parameters
@@ -356,7 +283,7 @@ class MlClient(NamespacedClient):
         """
         Predicts the future behavior of a time series by using its historical behavior.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-forecast.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-forecast.html>`_
 
         :arg job_id: The ID of the job to forecast for
         :arg duration: The duration of the forecast
@@ -390,7 +317,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves anomaly detection job results for one or more buckets.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-get-bucket.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-bucket.html>`_
 
         :arg job_id: ID of the job to get bucket results from
         :arg body: Bucket selection details if not provided in URI
@@ -428,7 +355,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves information about the scheduled events in calendars.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-get-calendar-event.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-calendar-event.html>`_
 
         :arg calendar_id: The ID of the calendar containing the events
         :arg end: Get events before this time
@@ -459,7 +386,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves configuration information for calendars.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-get-calendar.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-calendar.html>`_
 
         :arg body: The from and size parameters optionally sent in the
             body
@@ -486,7 +413,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves anomaly detection job results for one or more categories.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-get-category.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-category.html>`_
 
         :arg job_id: The name of the job
         :arg body: Category selection details if not provided in URI
@@ -520,7 +447,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves usage information for datafeeds.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-get-datafeed-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-datafeed-stats.html>`_
 
         :arg datafeed_id: The ID of the datafeeds stats to fetch
         :arg allow_no_datafeeds: Whether to ignore if a wildcard
@@ -537,12 +464,12 @@ class MlClient(NamespacedClient):
             headers=headers,
         )
 
-    @query_params("allow_no_datafeeds", "allow_no_match")
+    @query_params("allow_no_datafeeds", "allow_no_match", "exclude_generated")
     def get_datafeeds(self, datafeed_id=None, params=None, headers=None):
         """
         Retrieves configuration information for datafeeds.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-get-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeeds to fetch
         :arg allow_no_datafeeds: Whether to ignore if a wildcard
@@ -551,6 +478,8 @@ class MlClient(NamespacedClient):
         :arg allow_no_match: Whether to ignore if a wildcard expression
             matches no datafeeds. (This includes `_all` string or when no datafeeds
             have been specified)
+        :arg exclude_generated: Omits fields that are illegal to set on
+            datafeed PUT
         """
         return self.transport.perform_request(
             "GET",
@@ -564,7 +493,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves filters.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-get-filter.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-filter.html>`_
 
         :arg filter_id: The ID of the filter to fetch
         :arg from_: skips a number of filters
@@ -595,7 +524,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves anomaly detection job results for one or more influencers.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-get-influencer.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-influencer.html>`_
 
         :arg job_id: Identifier for the anomaly detection job
         :arg body: Influencer selection criteria
@@ -630,7 +559,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves usage information for anomaly detection jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-get-job-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-job-stats.html>`_
 
         :arg job_id: The ID of the jobs stats to fetch
         :arg allow_no_jobs: Whether to ignore if a wildcard expression
@@ -647,12 +576,12 @@ class MlClient(NamespacedClient):
             headers=headers,
         )
 
-    @query_params("allow_no_jobs", "allow_no_match")
+    @query_params("allow_no_jobs", "allow_no_match", "exclude_generated")
     def get_jobs(self, job_id=None, params=None, headers=None):
         """
         Retrieves configuration information for anomaly detection jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-get-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-job.html>`_
 
         :arg job_id: The ID of the jobs to fetch
         :arg allow_no_jobs: Whether to ignore if a wildcard expression
@@ -661,6 +590,8 @@ class MlClient(NamespacedClient):
         :arg allow_no_match: Whether to ignore if a wildcard expression
             matches no jobs. (This includes `_all` string or when no jobs have been
             specified)
+        :arg exclude_generated: Omits fields that are illegal to set on
+            job PUT
         """
         return self.transport.perform_request(
             "GET",
@@ -676,7 +607,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves information about model snapshots.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-get-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-snapshot.html>`_
 
         :arg job_id: The ID of the job to fetch
         :arg body: Model snapshot selection criteria
@@ -722,7 +653,7 @@ class MlClient(NamespacedClient):
         Retrieves overall bucket results that summarize the bucket results of multiple
         anomaly detection jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-get-overall-buckets.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-overall-buckets.html>`_
 
         :arg job_id: The job IDs for which to calculate overall bucket
             results
@@ -774,7 +705,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves anomaly records for an anomaly detection job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-get-record.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-record.html>`_
 
         :arg job_id: The ID of the job
         :arg body: Record selection criteria
@@ -808,7 +739,7 @@ class MlClient(NamespacedClient):
         """
         Returns defaults and limits used by machine learning.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/get-ml-info.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/get-ml-info.html>`_
         """
         return self.transport.perform_request(
             "GET", "/_ml/info", params=params, headers=headers
@@ -819,7 +750,7 @@ class MlClient(NamespacedClient):
         """
         Opens one or more anomaly detection jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-open-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-open-job.html>`_
 
         :arg job_id: The ID of the job to open
         """
@@ -838,7 +769,7 @@ class MlClient(NamespacedClient):
         """
         Posts scheduled events in a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-post-calendar-event.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-post-calendar-event.html>`_
 
         :arg calendar_id: The ID of the calendar to modify
         :arg body: A list of events
@@ -860,7 +791,7 @@ class MlClient(NamespacedClient):
         """
         Sends data to an anomaly detection job for analysis.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-post-data.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-post-data.html>`_
 
         :arg job_id: The name of the job receiving the data
         :arg body: The data to process
@@ -887,7 +818,7 @@ class MlClient(NamespacedClient):
         """
         Previews a datafeed.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-preview-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-preview-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to preview
         """
@@ -908,7 +839,7 @@ class MlClient(NamespacedClient):
         """
         Instantiates a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-put-calendar.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-put-calendar.html>`_
 
         :arg calendar_id: The ID of the calendar to create
         :arg body: The calendar details
@@ -931,7 +862,7 @@ class MlClient(NamespacedClient):
         """
         Adds an anomaly detection job to a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-put-calendar-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-put-calendar-job.html>`_
 
         :arg calendar_id: The ID of the calendar to modify
         :arg job_id: The ID of the job to add to the calendar
@@ -954,7 +885,7 @@ class MlClient(NamespacedClient):
         """
         Instantiates a datafeed.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-put-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-put-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to create
         :arg body: The datafeed config
@@ -985,7 +916,7 @@ class MlClient(NamespacedClient):
         """
         Instantiates a filter.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-put-filter.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-put-filter.html>`_
 
         :arg filter_id: The ID of the filter to create
         :arg body: The filter details
@@ -1007,7 +938,7 @@ class MlClient(NamespacedClient):
         """
         Instantiates an anomaly detection job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-put-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-put-job.html>`_
 
         :arg job_id: The ID of the job to create
         :arg body: The job
@@ -1031,7 +962,7 @@ class MlClient(NamespacedClient):
         """
         Reverts to a specific snapshot.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-revert-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-revert-snapshot.html>`_
 
         :arg job_id: The ID of the job to fetch
         :arg snapshot_id: The ID of the snapshot to revert to
@@ -1064,7 +995,7 @@ class MlClient(NamespacedClient):
         Sets a cluster wide upgrade_mode setting that prepares machine learning indices
         for an upgrade.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-set-upgrade-mode.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-set-upgrade-mode.html>`_
 
         :arg enabled: Whether to enable upgrade_mode ML setting or not.
             Defaults to false.
@@ -1080,7 +1011,7 @@ class MlClient(NamespacedClient):
         """
         Starts one or more datafeeds.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-start-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-start-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to start
         :arg body: The start datafeed parameters
@@ -1108,7 +1039,7 @@ class MlClient(NamespacedClient):
         """
         Stops one or more datafeeds.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-stop-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-stop-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to stop
         :arg body: The URL params optionally sent in the body
@@ -1142,7 +1073,7 @@ class MlClient(NamespacedClient):
         """
         Updates certain properties of a datafeed.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-update-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-update-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to update
         :arg body: The datafeed update settings
@@ -1173,7 +1104,7 @@ class MlClient(NamespacedClient):
         """
         Updates the description of a filter, adds items, or removes items.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-update-filter.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-update-filter.html>`_
 
         :arg filter_id: The ID of the filter to update
         :arg body: The filter update
@@ -1195,7 +1126,7 @@ class MlClient(NamespacedClient):
         """
         Updates certain properties of an anomaly detection job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-update-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-update-job.html>`_
 
         :arg job_id: The ID of the job to create
         :arg body: The job update settings
@@ -1219,7 +1150,7 @@ class MlClient(NamespacedClient):
         """
         Updates certain properties of a snapshot.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-update-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-update-snapshot.html>`_
 
         :arg job_id: The ID of the job to fetch
         :arg snapshot_id: The ID of the snapshot to update
@@ -1289,11 +1220,11 @@ class MlClient(NamespacedClient):
         """
         Deletes an existing data frame analytics job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/delete-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/delete-dfanalytics.html>`_
 
         .. warning::
 
-            This API is **experimental** so may include breaking changes
+            This API is **beta** so may include breaking changes
             or be removed in a future version
 
         :arg id: The ID of the data frame analytics to delete
@@ -1316,11 +1247,11 @@ class MlClient(NamespacedClient):
         """
         Evaluates the data frame analytics for an annotated index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/evaluate-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/evaluate-dfanalytics.html>`_
 
         .. warning::
 
-            This API is **experimental** so may include breaking changes
+            This API is **beta** so may include breaking changes
             or be removed in a future version
 
         :arg body: The evaluation definition
@@ -1336,22 +1267,24 @@ class MlClient(NamespacedClient):
             body=body,
         )
 
-    @query_params("allow_no_match", "from_", "size")
+    @query_params("allow_no_match", "exclude_generated", "from_", "size")
     def get_data_frame_analytics(self, id=None, params=None, headers=None):
         """
         Retrieves configuration information for data frame analytics jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/get-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/get-dfanalytics.html>`_
 
         .. warning::
 
-            This API is **experimental** so may include breaking changes
+            This API is **beta** so may include breaking changes
             or be removed in a future version
 
         :arg id: The ID of the data frame analytics to fetch
         :arg allow_no_match: Whether to ignore if a wildcard expression
             matches no data frame analytics. (This includes `_all` string or when no
             data frame analytics have been specified)  Default: True
+        :arg exclude_generated: Omits fields that are illegal to set on
+            data frame analytics PUT
         :arg from_: skips a number of analytics
         :arg size: specifies a max number of analytics to get  Default:
             100
@@ -1372,11 +1305,11 @@ class MlClient(NamespacedClient):
         """
         Retrieves usage information for data frame analytics jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/get-dfanalytics-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/get-dfanalytics-stats.html>`_
 
         .. warning::
 
-            This API is **experimental** so may include breaking changes
+            This API is **beta** so may include breaking changes
             or be removed in a future version
 
         :arg id: The ID of the data frame analytics stats to fetch
@@ -1404,11 +1337,11 @@ class MlClient(NamespacedClient):
         """
         Instantiates a data frame analytics job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/put-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/put-dfanalytics.html>`_
 
         .. warning::
 
-            This API is **experimental** so may include breaking changes
+            This API is **beta** so may include breaking changes
             or be removed in a future version
 
         :arg id: The ID of the data frame analytics to create
@@ -1431,11 +1364,11 @@ class MlClient(NamespacedClient):
         """
         Starts a data frame analytics job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/start-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/start-dfanalytics.html>`_
 
         .. warning::
 
-            This API is **experimental** so may include breaking changes
+            This API is **beta** so may include breaking changes
             or be removed in a future version
 
         :arg id: The ID of the data frame analytics to start
@@ -1459,11 +1392,11 @@ class MlClient(NamespacedClient):
         """
         Stops one or more data frame analytics jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/stop-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/stop-dfanalytics.html>`_
 
         .. warning::
 
-            This API is **experimental** so may include breaking changes
+            This API is **beta** so may include breaking changes
             or be removed in a future version
 
         :arg id: The ID of the data frame analytics to stop
@@ -1493,11 +1426,11 @@ class MlClient(NamespacedClient):
         Deletes an existing trained inference model that is currently not referenced by
         an ingest pipeline.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/delete-trained-models.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/delete-trained-models.html>`_
 
         .. warning::
 
-            This API is **experimental** so may include breaking changes
+            This API is **beta** so may include breaking changes
             or be removed in a future version
 
         :arg model_id: The ID of the trained model to delete
@@ -1519,11 +1452,11 @@ class MlClient(NamespacedClient):
         """
         Explains a data frame analytics config.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/explain-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/explain-dfanalytics.html>`_
 
         .. warning::
 
-            This API is **experimental** so may include breaking changes
+            This API is **beta** so may include breaking changes
             or be removed in a future version
 
         :arg body: The data frame analytics config to explain
@@ -1540,7 +1473,7 @@ class MlClient(NamespacedClient):
     @query_params(
         "allow_no_match",
         "decompress_definition",
-        "for_export",
+        "exclude_generated",
         "from_",
         "include",
         "include_model_definition",
@@ -1551,11 +1484,11 @@ class MlClient(NamespacedClient):
         """
         Retrieves configuration information for a trained inference model.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/get-trained-models.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/get-trained-models.html>`_
 
         .. warning::
 
-            This API is **experimental** so may include breaking changes
+            This API is **beta** so may include breaking changes
             or be removed in a future version
 
         :arg model_id: The ID of the trained models to fetch
@@ -1565,8 +1498,8 @@ class MlClient(NamespacedClient):
         :arg decompress_definition: Should the model definition be
             decompressed into valid JSON or returned in a custom compressed format.
             Defaults to true.  Default: True
-        :arg for_export: Omits fields that are illegal to set on model
-            PUT
+        :arg exclude_generated: Omits fields that are illegal to set on
+            model PUT
         :arg from_: skips a number of trained models
         :arg include: A comma-separate list of fields to optionally
             include. Valid options are 'definition' and 'total_feature_importance'.
@@ -1595,11 +1528,11 @@ class MlClient(NamespacedClient):
         """
         Retrieves usage information for trained inference models.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/get-trained-models-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/get-trained-models-stats.html>`_
 
         .. warning::
 
-            This API is **experimental** so may include breaking changes
+            This API is **beta** so may include breaking changes
             or be removed in a future version
 
         :arg model_id: The ID of the trained models stats to fetch
@@ -1626,11 +1559,11 @@ class MlClient(NamespacedClient):
         """
         Creates an inference trained model.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/put-trained-models.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/put-trained-models.html>`_
 
         .. warning::
 
-            This API is **experimental** so may include breaking changes
+            This API is **beta** so may include breaking changes
             or be removed in a future version
 
         :arg model_id: The ID of the trained models to store
@@ -1653,7 +1586,7 @@ class MlClient(NamespacedClient):
         """
         Estimates the model memory
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/ml-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-apis.html>`_
 
         :arg body: The analysis config, plus cardinality estimates for
             fields it references
@@ -1674,11 +1607,11 @@ class MlClient(NamespacedClient):
         """
         Updates certain properties of a data frame analytics job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/update-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/update-dfanalytics.html>`_
 
         .. warning::
 
-            This API is **experimental** so may include breaking changes
+            This API is **beta** so may include breaking changes
             or be removed in a future version
 
         :arg id: The ID of the data frame analytics to update
@@ -1695,3 +1628,108 @@ class MlClient(NamespacedClient):
             headers=headers,
             body=body,
         )
+
+    @query_params("timeout", "wait_for_completion")
+    def upgrade_job_snapshot(self, job_id, snapshot_id, params=None, headers=None):
+        """
+        Upgrades a given job snapshot to the current major version.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-upgrade-job-model-snapshot.html>`_
+
+        :arg job_id: The ID of the job
+        :arg snapshot_id: The ID of the snapshot
+        :arg timeout: How long should the API wait for the job to be
+            opened and the old snapshot to be loaded.
+        :arg wait_for_completion: Should the request wait until the task
+            is complete before responding to the caller. Default is false.
+        """
+        for param in (job_id, snapshot_id):
+            if param in SKIP_IN_PATH:
+                raise ValueError("Empty value passed for a required argument.")
+
+        return self.transport.perform_request(
+            "POST",
+            _make_path(
+                "_ml",
+                "anomaly_detectors",
+                job_id,
+                "model_snapshots",
+                snapshot_id,
+                "_upgrade",
+            ),
+            params=params,
+            headers=headers,
+        )
+
+    @query_params(
+        "charset",
+        "column_names",
+        "delimiter",
+        "explain",
+        "format",
+        "grok_pattern",
+        "has_header_row",
+        "line_merge_size_limit",
+        "lines_to_sample",
+        "quote",
+        "should_trim_fields",
+        "timeout",
+        "timestamp_field",
+        "timestamp_format",
+    )
+    def find_file_structure(self, body, params=None, headers=None):
+        """
+        Finds the structure of a text file. The text file must contain data that is
+        suitable to be ingested into Elasticsearch.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/find-structure.html>`_
+
+        .. warning::
+
+            This API is **experimental** so may include breaking changes
+            or be removed in a future version
+
+        :arg body: The contents of the file to be analyzed
+        :arg charset: Optional parameter to specify the character set of
+            the file
+        :arg column_names: Optional parameter containing a comma
+            separated list of the column names for a delimited file
+        :arg delimiter: Optional parameter to specify the delimiter
+            character for a delimited file - must be a single character
+        :arg explain: Whether to include a commentary on how the
+            structure was derived
+        :arg format: Optional parameter to specify the high level file
+            format  Valid choices: ndjson, xml, delimited, semi_structured_text
+        :arg grok_pattern: Optional parameter to specify the Grok
+            pattern that should be used to extract fields from messages in a semi-
+            structured text file
+        :arg has_header_row: Optional parameter to specify whether a
+            delimited file includes the column names in its first row
+        :arg line_merge_size_limit: Maximum number of characters
+            permitted in a single message when lines are merged to create messages.
+            Default: 10000
+        :arg lines_to_sample: How many lines of the file should be
+            included in the analysis  Default: 1000
+        :arg quote: Optional parameter to specify the quote character
+            for a delimited file - must be a single character
+        :arg should_trim_fields: Optional parameter to specify whether
+            the values between delimiters in a delimited file should have whitespace
+            trimmed from them
+        :arg timeout: Timeout after which the analysis will be aborted
+            Default: 25s
+        :arg timestamp_field: Optional parameter to specify the
+            timestamp field in the file
+        :arg timestamp_format: Optional parameter to specify the
+            timestamp format in the file - may be either a Joda or Java time format
+        """
+        if body in SKIP_IN_PATH:
+            raise ValueError("Empty value passed for a required argument 'body'.")
+
+        body = _bulk_body(self.transport.serializer, body)
+        return self.transport.perform_request(
+            "POST",
+            "/_ml/find_file_structure",
+            params=params,
+            headers=headers,
+            body=body,
+        )
